NopStopper
==========

.. currentmodule:: pykeen.stoppers

.. autoclass:: NopStopper
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~NopStopper.get_summary_dict
      ~NopStopper.should_evaluate
      ~NopStopper.should_stop

   .. rubric:: Methods Documentation

   .. automethod:: get_summary_dict
   .. automethod:: should_evaluate
   .. automethod:: should_stop
